@@ -11,6 +11,7 @@ import json
 import shapefile #pip pyshp
 
 import geofeatures
+import log
 
 def shp2geojson(inFilename,outFilename,clip_rect=None):
     # read the shapefile
@@ -19,12 +20,20 @@ def shp2geojson(inFilename,outFilename,clip_rect=None):
     fieldNames = [field[0] for field in fields]
     #print 'fieldNames', fieldNames
     features = []
+    skipped_no_points = 0
     for (sr, ss) in itertools.izip(reader.iterRecords(), reader.iterShapes()):
+        if len(ss.points) == 0: 
+            skipped_no_points += 1
+            continue  
         atr = dict(zip(fieldNames, sr))
         geom = ss.__geo_interface__
         if not clip_rect or geofeatures.coordinates_intersect_rect_q(geom['coordinates'],clip_rect):
             #print 'DEB geom:', geom
             features.append(dict(type='Feature', geometry=geom, properties=atr)) 
+
+    # log messages
+    if skipped_no_points > 0:
+        log.warning("Skipped %d shapes in %s because they have no geometry.", skipped_no_points, inFilename)
  
     # write the geojson file
     jsonFile = open(outFilename, 'w')
